package #
  Path::Extended::Test::Dir;

use strict;
use warnings;
use base qw( Path::Extended::Dir );

1;
